@@ -10,10 +10,10 @@
 // ┃ of the [Apache License 2.0](https://www.apache.org/licenses/LICENSE-2.0). ┃
 // ┗━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━━┛
 
+pub mod client_async;
 pub mod client_sync;
 mod pandas;
 mod polars;
 mod pyarrow;
-pub mod python;
 pub mod table_data;
 pub mod update_data;
